Crate kcr_forklift_konveyor_io

Crate kcr_forklift_konveyor_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the forklift.konveyor.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

forklift.konveyor.io/v1beta1

  • ForkliftController
  • Hook
  • Host
  • Migration
  • NetworkMap
  • OpenstackVolumePopulator
  • OvirtVolumePopulator
  • Plan
  • Provider
  • StorageMap

Modules

v1beta1